# GIF2TTY: Show GIF to TTY

You can use this package to convert gif file into a list of ascii frames, and as the package name says, it can also show these frames on tty device as you wish.

## Installation

```bash
$ pip install gif2tty
```
